@@ -1,6 +1,8 @@
 #' gnfit
 #'
-#' This function provides some useful statistics to assess the quality of fit of generalized log-gamma probabilistic model, including the statistics Cramer-von Mises and Anderson-Darling. It can also calculate other goodness of fit such as Hannan-Quin Information Criterion and Kolmogorov-Smirnov test.
+#' This function provides some useful statistics to assess the quality of fit of generalized log-gamma probabilistic model,
+#' including the statistics Cramer-von Mises and Anderson-Darling. It can also calculate other goodness of fit such as Hannan-Quin Information Criterion
+#' and Kolmogorov-Smirnov test.
 
 #' @param starts numeric vector. Initial parameters to maximize the likelihood function
 #' @param data numeric vector. A sample of a generalized log-gamma distribution.
@@ -8,8 +10,11 @@
 #' @author Carlos Alberto Cardozo Delgado <cardozorpackages@gmail.com>, G. Paula and L. Vanegas.
 #' @examples
 #' \dontrun{
-#' set.seed(12)
-#' sample <- rglg(100,location=0,scale=0.5,shape=0.75)
+#' set.seed(1)
+#' # The size of the sample must be median or large to obtain a good estimates
+#' n <- 100
+#' sample <- rglg(n,location=0,scale=0.5,shape=0.75)
+#' # This step takes a few minutes.
 #' result <- gnfit(starts=c(0.1,0.75,1),data=sample)
 #' result
 #' }
@@ -21,17 +26,18 @@ gnfit <- function(starts,data){
                     a <- par[1]
                     b <- par[2]
                     c <- par[3]
-                    dloggamma(x, mu = a, sigma = b, lambda= c)
+                    dglg(x, location = a, scale = b, shape = c)
          }
          cdf_glg <- function(par,x){
                     a <- par[1]
                     b <- par[2]
                     c <- par[3]
-                    ploggamma(x, mu = a, sigma = b, lambda = c)
+                    pglg(x, location = a, scale = b, shape = c)
          }
          sample <- data
+         sample_domain <- mean(sample) + (sd(sample)/sqrt(length(sample)))*c(qnorm(0.98),qnorm(0.98))
          output <- suppressWarnings(goodness.fit(pdf = pdf_glg, cdf = cdf_glg, starts = starts, data = sample,
-                        method = "PSO", lim_inf = c(-20,0,-5), lim_sup = c(20,10,5),mle = NULL,domain=c(-Inf,Inf)))
+                        method = "PSO", lim_inf = c(-20,0,-5), lim_sup = c(20,10,5),mle = NULL,domain=sample_domain))
          x = seq(floor(min(sample)) - 0.5, ceiling(max(sample)) + 0.5, length.out = 500)
 
          f_x <- pdf_glg(par = output$mle, x)
